@@ -15,7 +15,7 @@
 
 #define WEAK_SELF(weakSelf)  __weak __typeof(&*self)weakSelf = self;
 
-static NSString *const JPushConfig_FileName     = @"PushConfig";
+static NSString *const JPushConfig_FileName     = @"JPushConfig";
 static NSString *const JPushConfig_Appkey       = @"Appkey";
 static NSString *const JPushConfig_Channel      = @"Channel";
 static NSString *const JPushConfig_IsProduction = @"IsProduction";
@@ -24,7 +24,7 @@ static NSString *const JPushConfig_Delay        = @"Delay";
 
 static NSString *const JPushDocumentEvent_ReceiveNotification       = @"receiveNotification";
 static NSString *const JPushDocumentEvent_OpenNotification          = @"openNotification";
-static NSString *const JPushDocumentEvent_BackgroundNotification    = @"backgroundNotification";
+static NSString *const JPushDocumentEvent_BackgroundNotification    = @"backgroundNotification";
 static NSString *const JPushDocumentEvent_SetTagsWithAlias          = @"setTagsWithAlias";
 static NSString *const JPushDocumentEvent_ReceiveMessage            = @"receiveMessage";
 static NSString *const JPushDocumentEvent_StartLocalNotification    = @"startLocalNotification";
